#!/bin/sh
#------------------------------------------------------------------------
# PKCertTool-upgrade.sh - Shell script to aid in upgrading old PKCertTool
# databases to the new format.
# PKCertTool: $Revision: 1$   $Modtime: Tuesday, January 19, 2010 10:59:28 AM$
# Copyright 2010 by PKWARE, Inc.  All Rights Reserved.
#------------------------------------------------------------------------

# Modify this section if you don't trust your PATH environment variable!
# Please note that the following programs must either be on your PATH, or have
# their full path specified below. This script is intended to be run as the
# super user, so these programs will run with full super user access.
# Also note that if you set the COPYACL command, any ACL (Access Control List)
# on the original database will be copied to the new database. COPYACL is not
# set by default.
CUT=cut
ECHO=echo
GREP=grep
PKCERTTOOL=pkcerttool
STRINGS=strings
TEST=test
COPYACL=""
# Uncomment this section to set COPYACL to a reasonable value for your system
#case `uname`
#   AIX)
#      COPYACL="aclget \"${CERTDB}.old\" | aclput \"${CERTDB}\""
#      ;;
#   FreeBSD)
#      COPYACL="getfacl \"${CERTDB}.old\" | setfacl -b -n -M - \"${CERTDB}\""
#      ;;
#   HP-UX)
#      COPYACL="chacl -f \"${CERTDB}.old\" \"${CERTDB}\""
#      ;;
#   Linux)
#      COPYACL="getfacl \"${CERTDB}.old\" | setfacl --set-file=- \"${CERTDB}\""
#      ;;
#   SunOS)
#      COPYACL="getfacl \"${CERTDB}.old\" | setfacl -f - \"${CERTDB}\""
#      ;;
#esac


# The rest of this script should NOT be modified.
CERTDB=$1
FOUND="0"
PATTERN="[(MY)|(Other)|(CA)|(Root)]Certificates"

if ${TEST} "X${CERTDB}" = "X" ; then
   ${ECHO} "No file was specified to convert!"
   ${ECHO}
   ${ECHO} "Usage:"
   ${ECHO} "$0 <dbfile>"
   ${ECHO} "        <dbfile> - The full path to a certificates.db file to be upgraded"
   ${ECHO}
   exit 1
fi

if ${TEST} -f ${PKCERTTOOL} ; then
   if ${TEST} -x ${PKCERTTOOL} ; then
      SEP=`${ECHO} "${PKCERTTOOL}" | ${CUT} -d "/" -f1 -s`
      if ${TEST} "X${SEP}" = "X" ; then
	 PKCERTTOOL="./${PKCERTTOOL}"
      fi
   else
      ${ECHO} "Cannot execute '${PKCERTTOOL}'! Exiting now!"
      exit 1;
   fi
else
   # It's not a relative or full path designation, so let's see if it's on
   # the path!
   ${PKCERTTOOL} > /dev/null 2> /dev/null
   RET=$?
   if ! ${TEST} ${RET} = "3" ; then
      ${ECHO} "Cannot find '${PKCERTTOOL}'! Exiting now!"
      exit 1;
   fi
fi

${STRINGS} -a "${CERTDB}" | ${GREP} "** This file contains an SQLite 2.1 database **" > /dev/null 2> /dev/null
RET=$?
if ${TEST} ${RET} = "0"; then
   ${STRINGS} -a "${CERTDB}" | ${GREP} "${PATTERN}" > /dev/null 2> /dev/null
   RET=$?
   if ${TEST} ${RET} = "0"; then
      ${PKCERTTOOL} -upgrade -database "${CERTDB}"
      RET=$?
      # If the upgrade was successful, and we have a COPYACL command set,
      # run it.
      if ${TEST} ${RET} = "0"; then
        if ! ${TEST} "X${COPYACL}" = "X" ; then
           /bin/sh -c ${COPYACL}
        fi
      fi
      FOUND="1"
   fi
fi

if ! ${TEST} "${FOUND}" = "1" ; then
   ${ECHO} "Skipping: ${CERTDB}"
fi
